@@ -1,5 +1,3 @@
-import Report from './report';
-
 /**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -33,6 +31,9 @@ export enum ReportTypes {
   ERROR = '/browser/errorLog',
   ERRORS = '/browser/errorLogs',
   PERF = '/browser/perfData',
+  WEBVITALS = '/browser/perfData/webVitals',
+  WEBINTERACTIONS = '/browser/perfData/webInteractions',
+  RESOURCES = '/browser/perfData/resources',
   SEGMENT = '/v3/segment',
   SEGMENTS = '/v3/segments',
 }
