@@ -30,6 +30,7 @@ class TaskQueue {
     if (!(this.queues && this.queues.length)) {
       return;
     }
+
     new Report('ERRORS', this.collector).sendByXhr(this.queues);
     this.queues = [];
   }
@@ -39,7 +40,7 @@ class TaskQueue {
       if (!this.queues.length) {
         return;
       }
-      new Report('ERRORS', this.collector).sendByXhr(this.queues);
+      new Report('ERRORS', this.collector).sendByBeacon(this.queues);
     });
   }
 }
