@@ -15,8 +15,8 @@
  * limitations under the License.
  */
 
-import xhrInterceptor from './interceptors/xhr';
-import windowFetch from './interceptors/fetch';
+import xhrInterceptor, { setOptions } from './interceptors/xhr';
+import windowFetch, { setFetchOptions } from './interceptors/fetch';
 import Report from '../services/report';
 import { SegmentFields } from './type';
 import { CustomOptionsType } from '../types';
@@ -30,7 +30,7 @@ export default function traceSegment(options: CustomOptionsType) {
     if (!segments.length) {
       return;
     }
-    new Report('SEGMENTS', options.collector).sendByXhr(segments);
+    new Report('SEGMENTS', options.collector).sendByBeacon(segments);
   });
   //report per options.traceTimeInterval min
   setInterval(() => {
@@ -41,3 +41,8 @@ export default function traceSegment(options: CustomOptionsType) {
     segments.splice(0, segments.length);
   }, options.traceTimeInterval);
 }
+
+export function setConfig(opt: CustomOptionsType) {
+  setOptions(opt);
+  setFetchOptions(opt);
+}
